/*! *****************************************************************************
Copyright (c) Microsoft Corporation.

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
PERFORMANCE OF THIS SOFTWARE.
***************************************************************************** */

var __assign = function() {
    __assign = Object.assign || function __assign(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};

function __awaiter(thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
}

function __generator(thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
    return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (_) try {
            if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [op[0] & 2, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
}

function __spreadArrays() {
    for (var s = 0, i = 0, il = arguments.length; i < il; i++) s += arguments[i].length;
    for (var r = Array(s), k = 0, i = 0; i < il; i++)
        for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++)
            r[k] = a[j];
    return r;
}

class PLazy extends Promise {
	constructor(executor) {
		super(resolve => {
			resolve();
		});

		this._executor = executor;
	}

	static from(fn) {
		return new PLazy(resolve => {
			resolve(fn());
		});
	}

	then(onFulfilled, onRejected) {
		this._promise = this._promise || new Promise(this._executor);
		// eslint-disable-next-line promise/prefer-await-to-then
		return this._promise.then(onFulfilled, onRejected);
	}

	catch(onRejected) {
		this._promise = this._promise || new Promise(this._executor);
		return this._promise.catch(onRejected);
	}
}

var pLazy = PLazy;

var commonjsGlobal = typeof globalThis !== 'undefined' ? globalThis : typeof window !== 'undefined' ? window : typeof global !== 'undefined' ? global : typeof self !== 'undefined' ? self : {};

function createCommonjsModule(fn, module) {
	return module = { exports: {} }, fn(module, module.exports), module.exports;
}

var loadjs_umd = createCommonjsModule(function (module, exports) {
(function(root, factory) {
  {
    module.exports = factory();
  }
}(commonjsGlobal, function() {
/**
 * Global dependencies.
 * @global {Object} document - DOM
 */

var devnull = function() {},
    bundleIdCache = {},
    bundleResultCache = {},
    bundleCallbackQueue = {};


/**
 * Subscribe to bundle load event.
 * @param {string[]} bundleIds - Bundle ids
 * @param {Function} callbackFn - The callback function
 */
function subscribe(bundleIds, callbackFn) {
  // listify
  bundleIds = bundleIds.push ? bundleIds : [bundleIds];

  var depsNotFound = [],
      i = bundleIds.length,
      numWaiting = i,
      fn,
      bundleId,
      r,
      q;

  // define callback function
  fn = function (bundleId, pathsNotFound) {
    if (pathsNotFound.length) depsNotFound.push(bundleId);

    numWaiting--;
    if (!numWaiting) callbackFn(depsNotFound);
  };

  // register callback
  while (i--) {
    bundleId = bundleIds[i];

    // execute callback if in result cache
    r = bundleResultCache[bundleId];
    if (r) {
      fn(bundleId, r);
      continue;
    }

    // add to callback queue
    q = bundleCallbackQueue[bundleId] = bundleCallbackQueue[bundleId] || [];
    q.push(fn);
  }
}


/**
 * Publish bundle load event.
 * @param {string} bundleId - Bundle id
 * @param {string[]} pathsNotFound - List of files not found
 */
function publish(bundleId, pathsNotFound) {
  // exit if id isn't defined
  if (!bundleId) return;

  var q = bundleCallbackQueue[bundleId];

  // cache result
  bundleResultCache[bundleId] = pathsNotFound;

  // exit if queue is empty
  if (!q) return;

  // empty callback queue
  while (q.length) {
    q[0](bundleId, pathsNotFound);
    q.splice(0, 1);
  }
}


/**
 * Execute callbacks.
 * @param {Object or Function} args - The callback args
 * @param {string[]} depsNotFound - List of dependencies not found
 */
function executeCallbacks(args, depsNotFound) {
  // accept function as argument
  if (args.call) args = {success: args};

  // success and error callbacks
  if (depsNotFound.length) (args.error || devnull)(depsNotFound);
  else (args.success || devnull)(args);
}


/**
 * Load individual file.
 * @param {string} path - The file path
 * @param {Function} callbackFn - The callback function
 */
function loadFile(path, callbackFn, args, numTries) {
  var doc = document,
      async = args.async,
      maxTries = (args.numRetries || 0) + 1,
      beforeCallbackFn = args.before || devnull,
      pathname = path.replace(/[\?|#].*$/, ''),
      pathStripped = path.replace(/^(css|img)!/, ''),
      isLegacyIECss,
      e;

  numTries = numTries || 0;

  if (/(^css!|\.css$)/.test(pathname)) {
    // css
    e = doc.createElement('link');
    e.rel = 'stylesheet';
    e.href = pathStripped;

    // tag IE9+
    isLegacyIECss = 'hideFocus' in e;

    // use preload in IE Edge (to detect load errors)
    if (isLegacyIECss && e.relList) {
      isLegacyIECss = 0;
      e.rel = 'preload';
      e.as = 'style';
    }
  } else if (/(^img!|\.(png|gif|jpg|svg|webp)$)/.test(pathname)) {
    // image
    e = doc.createElement('img');
    e.src = pathStripped;    
  } else {
    // javascript
    e = doc.createElement('script');
    e.src = path;
    e.async = async === undefined ? true : async;
  }

  e.onload = e.onerror = e.onbeforeload = function (ev) {
    var result = ev.type[0];

    // treat empty stylesheets as failures to get around lack of onerror
    // support in IE9-11
    if (isLegacyIECss) {
      try {
        if (!e.sheet.cssText.length) result = 'e';
      } catch (x) {
        // sheets objects created from load errors don't allow access to
        // `cssText` (unless error is Code:18 SecurityError)
        if (x.code != 18) result = 'e';
      }
    }

    // handle retries in case of load failure
    if (result == 'e') {
      // increment counter
      numTries += 1;

      // exit function and try again
      if (numTries < maxTries) {
        return loadFile(path, callbackFn, args, numTries);
      }
    } else if (e.rel == 'preload' && e.as == 'style') {
      // activate preloaded stylesheets
      return e.rel = 'stylesheet'; // jshint ignore:line
    }
    
    // execute callback
    callbackFn(path, result, ev.defaultPrevented);
  };

  // add to document (unless callback returns `false`)
  if (beforeCallbackFn(path, e) !== false) doc.head.appendChild(e);
}


/**
 * Load multiple files.
 * @param {string[]} paths - The file paths
 * @param {Function} callbackFn - The callback function
 */
function loadFiles(paths, callbackFn, args) {
  // listify paths
  paths = paths.push ? paths : [paths];

  var numWaiting = paths.length,
      x = numWaiting,
      pathsNotFound = [],
      fn,
      i;

  // define callback function
  fn = function(path, result, defaultPrevented) {
    // handle error
    if (result == 'e') pathsNotFound.push(path);

    // handle beforeload event. If defaultPrevented then that means the load
    // will be blocked (ex. Ghostery/ABP on Safari)
    if (result == 'b') {
      if (defaultPrevented) pathsNotFound.push(path);
      else return;
    }

    numWaiting--;
    if (!numWaiting) callbackFn(pathsNotFound);
  };

  // load scripts
  for (i=0; i < x; i++) loadFile(paths[i], fn, args);
}


/**
 * Initiate script load and register bundle.
 * @param {(string|string[])} paths - The file paths
 * @param {(string|Function|Object)} [arg1] - The (1) bundleId or (2) success
 *   callback or (3) object literal with success/error arguments, numRetries,
 *   etc.
 * @param {(Function|Object)} [arg2] - The (1) success callback or (2) object
 *   literal with success/error arguments, numRetries, etc.
 */
function loadjs(paths, arg1, arg2) {
  var bundleId,
      args;

  // bundleId (if string)
  if (arg1 && arg1.trim) bundleId = arg1;

  // args (default is {})
  args = (bundleId ? arg2 : arg1) || {};

  // throw error if bundle is already defined
  if (bundleId) {
    if (bundleId in bundleIdCache) {
      throw "LoadJS";
    } else {
      bundleIdCache[bundleId] = true;
    }
  }

  function loadFn(resolve, reject) {
    loadFiles(paths, function (pathsNotFound) {
      // execute callbacks
      executeCallbacks(args, pathsNotFound);
      
      // resolve Promise
      if (resolve) {
        executeCallbacks({success: resolve, error: reject}, pathsNotFound);
      }

      // publish bundle load event
      publish(bundleId, pathsNotFound);
    }, args);
  }
  
  if (args.returnPromise) return new Promise(loadFn);
  else loadFn();
}


/**
 * Execute callbacks when dependencies have been satisfied.
 * @param {(string|string[])} deps - List of bundle ids
 * @param {Object} args - success/error arguments
 */
loadjs.ready = function ready(deps, args) {
  // subscribe to bundle load event
  subscribe(deps, function (depsNotFound) {
    // execute callbacks
    executeCallbacks(args, depsNotFound);
  });

  return loadjs;
};


/**
 * Manually satisfy bundle dependencies.
 * @param {string} bundleId - The bundle id
 */
loadjs.done = function done(bundleId) {
  publish(bundleId, []);
};


/**
 * Reset loadjs dependencies statuses
 */
loadjs.reset = function reset() {
  bundleIdCache = {};
  bundleResultCache = {};
  bundleCallbackQueue = {};
};


/**
 * Determine if bundle has already been defined
 * @param String} bundleId - The bundle id
 */
loadjs.isDefined = function isDefined(bundleId) {
  return bundleId in bundleIdCache;
};


// export
return loadjs;

}));
});

/**
 * Created by: Andrey Polyakov (andrey@polyakov.im)
 */
/**
 * @ignore
 */
var getScriptLocation = function (scriptSelector) {
    var currentScript = document.currentScript;
    if (currentScript && currentScript instanceof HTMLScriptElement) {
        return currentScript;
    }
    var scriptId = document.getElementById(scriptSelector);
    if (scriptId && scriptId instanceof HTMLScriptElement) {
        return scriptId;
    }
    throw new Error("Can't find script element <script id=\"" + scriptSelector + "\" src=\"...\"></script>");
};

// wait until body is defined before injecting link. This ensures a non-blocking load in IE11.
/**
 * @ignore
 */
var ready = function (cb) {
    if (document.body) {
        return cb();
    }
    setTimeout(function () { return ready(cb); });
    return null;
};
/**
 * @ignore
 */
var getRef = function () {
    var refs = (document.body || document.getElementsByTagName('head')[0]).childNodes;
    return refs[refs.length - 1];
};
/**
 * @ignore
 */
var addElement = function (tag) {
    ready(function () {
        var ref = getRef();
        // Inject link
        // Note: the ternary preserves the existing behavior of 'before' argument, but we could choose to change the argument to 'after'
        // in a later release and standardize on ref.nextSibling for all refs
        // Note: `insertBefore` is used instead of `appendChild`, for safety re: http://www.paulirish.com/2011/surefire-dom-element-insertion/
        if (ref && ref.parentNode) {
            ref.parentNode.insertBefore(tag, ref.nextSibling);
        }
        else {
            document.head.appendChild(tag);
        }
    });
};
/**
 * @ignore
 */
var loadCSS = function (href) {
    return new Promise(function (resolve) {
        var ss = document.createElement('link');
        ss.rel = 'stylesheet';
        ss.href = href;
        // temporarily set media to something inapplicable to ensure it'll fetch without blocking render
        ss.media = 'only x';
        addElement(ss);
        // A method (exposed on return object for external use) that mimics onload by polling document.styleSheets until it includes the new sheet.
        var onLoadCssDefined = function (cb) {
            var resolvedHref = ss.href;
            var sheets = document.styleSheets;
            var i = sheets.length;
            i -= 1;
            while (i) {
                if (sheets[i].href === resolvedHref) {
                    return cb();
                }
                i -= 1;
            }
            setTimeout(function () { return onLoadCssDefined(cb); });
            return null;
        };
        var loadCB = function () {
            ss.removeEventListener('load', loadCB);
            ss.media = 'all';
            resolve(ss);
        };
        // once loaded, set link's media back to `all` so that the stylesheet applies once it loads
        if (ss.addEventListener) {
            ss.addEventListener('load', loadCB);
        }
        // @ts-ignore
        ss.onloadcssdefined = onLoadCssDefined;
        onLoadCssDefined(loadCB);
        return ss;
    });
};

self.fetch||(self.fetch=function(e,n){return n=n||{},new Promise(function(t,s){var r=new XMLHttpRequest,o=[],u=[],i={},a=function(){return {ok:2==(r.status/100|0),statusText:r.statusText,status:r.status,url:r.responseURL,text:function(){return Promise.resolve(r.responseText)},json:function(){return Promise.resolve(JSON.parse(r.responseText))},blob:function(){return Promise.resolve(new Blob([r.response]))},clone:a,headers:{keys:function(){return o},entries:function(){return u},get:function(e){return i[e.toLowerCase()]},has:function(e){return e.toLowerCase()in i}}}};for(var c in r.open(n.method||"get",e,!0),r.onload=function(){r.getAllResponseHeaders().replace(/^(.*?):[^\S\n]*([\s\S]*?)$/gm,function(e,n,t){o.push(n=n.toLowerCase()),u.push([n,t]),i[n]=i[n]?i[n]+","+t:t;}),t(a());},r.onerror=s,r.withCredentials="include"==n.credentials,n.headers)r.setRequestHeader(c,n.headers[c]);r.send(n.body||null);})});

var urlJoin = createCommonjsModule(function (module) {
(function (name, context, definition) {
  if ( module.exports) module.exports = definition();
  else context[name] = definition();
})('urljoin', commonjsGlobal, function () {

  function normalize (strArray) {
    var resultArray = [];
    if (strArray.length === 0) { return ''; }

    if (typeof strArray[0] !== 'string') {
      throw new TypeError('Url must be a string. Received ' + strArray[0]);
    }

    // If the first part is a plain protocol, we combine it with the next part.
    if (strArray[0].match(/^[^/:]+:\/*$/) && strArray.length > 1) {
      var first = strArray.shift();
      strArray[0] = first + strArray[0];
    }

    // There must be two or three slashes in the file protocol, two slashes in anything else.
    if (strArray[0].match(/^file:\/\/\//)) {
      strArray[0] = strArray[0].replace(/^([^/:]+):\/*/, '$1:///');
    } else {
      strArray[0] = strArray[0].replace(/^([^/:]+):\/*/, '$1://');
    }

    for (var i = 0; i < strArray.length; i++) {
      var component = strArray[i];

      if (typeof component !== 'string') {
        throw new TypeError('Url must be a string. Received ' + component);
      }

      if (component === '') { continue; }

      if (i > 0) {
        // Removing the starting slashes for each component but the first.
        component = component.replace(/^[\/]+/, '');
      }
      if (i < strArray.length - 1) {
        // Removing the ending slashes for each component but the last.
        component = component.replace(/[\/]+$/, '');
      } else {
        // For the last component we will combine multiple slashes to a single one.
        component = component.replace(/[\/]+$/, '/');
      }

      resultArray.push(component);

    }

    var str = resultArray.join('/');
    // Each input component is now separated by a single slash except the possible first plain protocol part.

    // remove trailing slash before parameters or hash
    str = str.replace(/\/(\?|&|#[^!])/g, '$1');

    // replace ? in parameters with &
    var parts = str.split('?');
    str = parts.shift() + (parts.length > 0 ? '?': '') + parts.join('&');

    return str;
  }

  return function () {
    var input;

    if (typeof arguments[0] === 'object') {
      input = arguments[0];
    } else {
      input = [].slice.call(arguments);
    }

    return normalize(input);
  };

});
});

var AsyncAssetsLoader = /** @class */ (function () {
    function AsyncAssetsLoader(props) {
        var _this = this;
        if (props === void 0) { props = {}; }
        this.props = {
            assetsPath: '/',
            assetsFile: 'assets.json',
            scriptSelector: 'assets-loader',
            chunkAttribute: 'data-chunks',
            baseChunks: [],
        };
        this.init = function () { return __awaiter(_this, void 0, void 0, function () {
            var assetContent, chunkList;
            var _this = this;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.fetchAssetContent()];
                    case 1:
                        assetContent = _a.sent();
                        chunkList = this.chunkList;
                        if (assetContent) {
                            chunkList.forEach(function (chunkName) {
                                if (assetContent[chunkName]) {
                                    var _a = assetContent[chunkName], _b = _a.css, css = _b === void 0 ? [] : _b, _c = _a.js, js = _c === void 0 ? [] : _c;
                                    if (js) {
                                        _this.loadJsChunkList(js);
                                    }
                                    if (css) {
                                        _this.loadCssChunkList(css);
                                    }
                                }
                            });
                        }
                        return [2 /*return*/];
                }
            });
        }); };
        /**
         * @ignore
         */
        this.fetchAssetContent = function () { return __awaiter(_this, void 0, void 0, function () {
            var _a, assetsDirUrl, currentScript, assetsFile, url, response, status_1, ok, e_1;
            var _b, _c;
            return __generator(this, function (_d) {
                switch (_d.label) {
                    case 0:
                        _a = this, assetsDirUrl = _a.assetsDirUrl, currentScript = _a.currentScript;
                        _d.label = 1;
                    case 1:
                        _d.trys.push([1, 5, , 6]);
                        assetsFile = (_c = (_b = currentScript.getAttribute('data-assets-file')) !== null && _b !== void 0 ? _b : this.props.assetsFile) !== null && _c !== void 0 ? _c : 'assets.json';
                        url = urlJoin([assetsDirUrl, assetsFile]);
                        return [4 /*yield*/, window.fetch(urlJoin([assetsDirUrl, assetsFile]))];
                    case 2:
                        response = _d.sent();
                        status_1 = response.status, ok = response.ok;
                        if (!ok) return [3 /*break*/, 4];
                        return [4 /*yield*/, response.json()];
                    case 3: return [2 /*return*/, _d.sent()];
                    case 4: throw new Error("There was an error while sending the request " + url + "[" + status_1.toString() + "]");
                    case 5:
                        e_1 = _d.sent();
                        console.error(e_1);
                        return [3 /*break*/, 6];
                    case 6: return [2 /*return*/];
                }
            });
        }); };
        /**
         * @ignore
         */
        this.loadCssChunkList = function (chunks) { return __awaiter(_this, void 0, void 0, function () {
            var _this = this;
            return __generator(this, function (_a) {
                if (typeof chunks === 'string') {
                    return [2 /*return*/, this.loadCssChunk(chunks)];
                }
                chunks.forEach(function (chunk) { return _this.loadCssChunk(chunk); });
                return [2 /*return*/];
            });
        }); };
        /**
         * @ignore
         */
        this.loadCssChunk = function (chunkFile) { return __awaiter(_this, void 0, void 0, function () {
            var url;
            return __generator(this, function (_a) {
                url = urlJoin([this.assetsDirUrl, chunkFile]);
                try {
                    return [2 /*return*/, new pLazy(function (resolve) { return resolve(loadCSS(url)); })];
                }
                catch (e) {
                    console.warn(e);
                }
                return [2 /*return*/];
            });
        }); };
        /**
         * @ignore
         */
        this.loadJsChunkList = function (chunks) { return __awaiter(_this, void 0, void 0, function () {
            var _this = this;
            return __generator(this, function (_a) {
                if (typeof chunks === 'string') {
                    return [2 /*return*/, this.loadJsChunk(chunks)];
                }
                chunks.forEach(function (chunk) { return _this.loadJsChunk(chunk); });
                return [2 /*return*/];
            });
        }); };
        /**
         * @ignore
         */
        this.loadJsChunk = function (chunkFile) { return __awaiter(_this, void 0, void 0, function () {
            var url;
            return __generator(this, function (_a) {
                url = urlJoin([this.assetsDirUrl, chunkFile]);
                try {
                    return [2 /*return*/, new pLazy(function (resolve) { return resolve(loadjs_umd(url, { returnPromise: true })); })];
                }
                catch (e) {
                    console.warn(e);
                }
                return [2 /*return*/];
            });
        }); };
        this.props = __assign(__assign({}, this.props), props);
    }
    Object.defineProperty(AsyncAssetsLoader.prototype, "currentScript", {
        /**
         * @ignore
         */
        get: function () {
            var _a = this.props.scriptSelector, scriptSelector = _a === void 0 ? 'assetsLoader' : _a;
            var scriptElement = getScriptLocation(scriptSelector);
            if (scriptElement) {
                return scriptElement;
            }
            else {
                throw new Error("Can't find script element");
            }
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(AsyncAssetsLoader.prototype, "chunkList", {
        /**
         * @ignore
         */
        get: function () {
            var _a;
            var _b = this.props, _c = _b.chunkAttribute, chunkAttribute = _c === void 0 ? 'data-chunks' : _c, _d = _b.baseChunks, baseChunks = _d === void 0 ? [] : _d, scriptSelector = _b.scriptSelector;
            var chunkList = __spreadArrays(baseChunks, ((_a = this.currentScript.getAttribute(chunkAttribute)) !== null && _a !== void 0 ? _a : '').split(','));
            if (chunkList.length) {
                return chunkList;
            }
            throw new Error("You need to specify list of chunks which you want to load in \"" + chunkAttribute + "\" attribute\n                <script " + chunkAttribute + "=\"...\" id=\"" + scriptSelector + "\" src=\"...\"\n        type=\"text/javascript\"></script>\n                ");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(AsyncAssetsLoader.prototype, "assetsDirUrl", {
        /**
         * @ignore
         */
        get: function () {
            var _a, _b;
            var currentScript = this.currentScript;
            var scriptElement = currentScript;
            var scriptElementSrc = scriptElement.getAttribute('src');
            if (scriptElementSrc) {
                var assetsPath = (_b = (_a = scriptElement.getAttribute('data-assets-path')) !== null && _a !== void 0 ? _a : this.props.assetsPath) !== null && _b !== void 0 ? _b : '/';
                var isAssetPathUrl = assetsPath.match(/^http(s?):\/\//);
                // When assetPath preset as url
                if (isAssetPathUrl) {
                    return assetsPath;
                }
                var loaderFolder = scriptElementSrc.substr(0, scriptElementSrc.lastIndexOf('/'));
                return urlJoin(loaderFolder, assetsPath);
            }
            return '';
        },
        enumerable: false,
        configurable: true
    });
    return AsyncAssetsLoader;
}());

export default AsyncAssetsLoader;
//# sourceMappingURL=async-assets-loader.es5.js.map
