"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.loadCSS = void 0;
// wait until body is defined before injecting link. This ensures a non-blocking load in IE11.
/**
 * @ignore
 */
var ready = function (cb) {
    if (document.body) {
        return cb();
    }
    setTimeout(function () { return ready(cb); });
    return null;
};
/**
 * @ignore
 */
var getRef = function () {
    var refs = (document.body || document.getElementsByTagName('head')[0]).childNodes;
    return refs[refs.length - 1];
};
/**
 * @ignore
 */
var addElement = function (tag) {
    ready(function () {
        var ref = getRef();
        // Inject link
        // Note: the ternary preserves the existing behavior of 'before' argument, but we could choose to change the argument to 'after'
        // in a later release and standardize on ref.nextSibling for all refs
        // Note: `insertBefore` is used instead of `appendChild`, for safety re: http://www.paulirish.com/2011/surefire-dom-element-insertion/
        if (ref && ref.parentNode) {
            ref.parentNode.insertBefore(tag, ref.nextSibling);
        }
        else {
            document.head.appendChild(tag);
        }
    });
};
/**
 * @ignore
 */
exports.loadCSS = function (href) {
    return new Promise(function (resolve) {
        var ss = document.createElement('link');
        ss.rel = 'stylesheet';
        ss.href = href;
        // temporarily set media to something inapplicable to ensure it'll fetch without blocking render
        ss.media = 'only x';
        addElement(ss);
        // A method (exposed on return object for external use) that mimics onload by polling document.styleSheets until it includes the new sheet.
        var onLoadCssDefined = function (cb) {
            var resolvedHref = ss.href;
            var sheets = document.styleSheets;
            var i = sheets.length;
            i -= 1;
            while (i) {
                if (sheets[i].href === resolvedHref) {
                    return cb();
                }
                i -= 1;
            }
            setTimeout(function () { return onLoadCssDefined(cb); });
            return null;
        };
        var loadCB = function () {
            ss.removeEventListener('load', loadCB);
            ss.media = 'all';
            resolve(ss);
        };
        // once loaded, set link's media back to `all` so that the stylesheet applies once it loads
        if (ss.addEventListener) {
            ss.addEventListener('load', loadCB);
        }
        // @ts-ignore
        ss.onloadcssdefined = onLoadCssDefined;
        onLoadCssDefined(loadCB);
        return ss;
    });
};
//# sourceMappingURL=css-loader.js.map